## `mlte`: Machine Learning Testing and Evaluation

`mlte` (pronounced "melt") is a toolkit for machine learning testing and evaluation.

[![Tests](https://github.com/turingcompl33t/mlte/actions/workflows/tests.yaml/badge.svg)](https://github.com/turingcompl33t/mlte/actions/workflows/tests.yaml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

### Getting Started

`mlte` is available on [PyPI](https://pypi.org/project/mlte-python/). Install the latest version with:

```bash
$ pip install mlte-python
```

Read the [documentation](https://mlte.readthedocs.io/en/latest/) for more details on getting started with `mlte`.
